==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-soap/src/test/java/org/apache/camel/converter/soap/name/QNameStrategyTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.converter.soap.name;

import javax.xml.namespace.QName;

import com.example.customerservice.GetCustomersByName;
import org.apache.camel.dataformat.soap.name.QNameStrategy;
import org.junit.Assert;
import org.junit.Test;

/**
 * 
 */
public class QNameStrategyTest {
    
    /**
     * The strategy should always produce the QName that
     * it was given on the constructor
     */
    @Test
    public void testQName() {
        QName elementName = new QName("http://my.name.org", "myElement");
        QNameStrategy strategy = new QNameStrategy(elementName);
        
        QName actualElementName = strategy.findQNameForSoapActionOrType(null, GetCustomersByName.class);
        Assert.assertEquals(elementName, actualElementName);
    }
}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/components/camel-soap/src/test/java/org/apache/camel/converter/soap/name/QNameStrategyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.converter.soap.name;

import javax.xml.namespace.QName;

import com.example.customerservice.GetCustomersByName;
import org.apache.camel.dataformat.soap.name.QNameStrategy;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class QNameStrategyTest {

    /**
     * The strategy should always produce the QName that it was given on the constructor
     */
    @Test
    public void testQName() {
        QName elementName = new QName("http://my.name.org", "myElement");
        QNameStrategy strategy = new QNameStrategy(elementName);

        QName actualElementName = strategy.findQNameForSoapActionOrType(null, GetCustomersByName.class);
        assertEquals(elementName, actualElementName);
    }
}
